CREATE TABLE IF NOT EXISTS admin (
  adm_login varchar(64) NOT NULL default '',
  adm_pass varchar(16) NOT NULL default '',
  path varchar(128) NOT NULL default '/web/disk4',
  max_email int(12) NOT NULL default '3',
  max_ftp int(12) NOT NULL default '3',
  quota int(11) NOT NULL default '50',
  bandwidth_per_month_mb INT ( 11 ) NOT NULL default '100',
  expire date NOT NULL default '0000-00-00',
  id_client int(9) NOT NULL default '0',
  pass_next_req varchar(128) NOT NULL default '0',
  pass_expire int(12) NOT NULL default '0',
  allow_add_domain enum('yes','no','check') NOT NULL default 'check',
  nbrdb int(9) NOT NULL default '1',
  resseller_flag enum('yes','no') NOT NULL default 'no',
  ssh_login_flag enum('yes','no') NOT NULL default 'no',
  ftp_login_flag enum('yes','no') NOT NULL default 'yes',
  pkg_install_flag enum('yes','no') NOT NULL default 'yes',
  ob_head varchar(64) NOT NULL default '',
  ob_tail varchar(64) NOT NULL default '',
  ob_next varchar(64) NOT NULL default '',
  last_used_lang varchar(32) NOT NULL default 'en_US',
  PRIMARY KEY  (adm_login),
  UNIQUE KEY adm_login (adm_login),
  UNIQUE KEY path (path)
)TYPE=MyISAM
